#! /bin/sh
# Project MULTIVOL -- input/output from/to multiple volumes with support of
#                     external scripts
# medium_changer.sh -- Changes medium.
# Marc SCHAEFER <schaefer@alphanet.ch>
# Creation: 08/02/97
# Update:   21/10/98
# V2.0 PV003
# DESCRIPTION
#    This script changes a medium with an autochanger.
# RESULT
#    0 ok, tape online
#    1 error
#    2 fatal error (parameters)
# NOTES
#    - medium changer software must be able to know which generic
#      interface or medium changer interface corresponds to which drive.
#    - next_medium must be implementable somehow (by passing the
#      current tape number as argument).
#    - Implementation DILOG Libra8 specific.
# BUGS
# TODO
# COPYING-POLICY
#   GPL
# BASED-ON
#   No previous work. First version (V2.0 is the project version).
# MODIFICATION-HISTORY
#    21/10/98  schaefer  plt in /usr/local/bin
#    23/10/98  schaefer  Ensured no echo in stdin
# $Id: medium_changer.sh,v 1.3 1998/10/23 16:34:50 schaefer Exp $

MEDIUM_CHANGER_COMMAND=/usr/local/bin/plt

if [ $# != 2 ]; then
   echo "$0 tape_device tape_number"
   echo "$0: bad args."
   exit 2
fi

TAPE_DEVICE=$1
TAPE_NUMBER=$2

case $TAPE_DEVICE in
   /dev/st0) MEDIUM_CHANGER_DEVICE=/dev/sgb
             TAPE_UNIT_ELEMENT=1;;
   *) MEDIUM_CHANGER_DEVICE=/dev/unknown
      TAPE_UNIT_ELEMENT=0;;
esac

if [ $TAPE_NUMBER = 1 ]; then
   $MEDIUM_CHANGER_COMMAND --medium_changer $MEDIUM_CHANGER_DEVICE --direct_command move_medium  0 `expr $TAPE_NUMBER + 1` $TAPE_UNIT_ELEMENT 1>&2
else
   $MEDIUM_CHANGER_COMMAND --medium_changer $MEDIUM_CHANGER_DEVICE --direct_command move_medium  0 $TAPE_UNIT_ELEMENT `expr $TAPE_NUMBER` 1>&2
   $MEDIUM_CHANGER_COMMAND --medium_changer $MEDIUM_CHANGER_DEVICE --direct_command move_medium  0 `expr $TAPE_NUMBER + 1` $TAPE_UNIT_ELEMENT 1>&2
fi
exit 0
