#! /bin/sh
# Project MULTIVOL -- input/output from/to multiple volumes with support of
#                     external scripts
# tape_init.sh -- Initializes tape device script.
# Marc SCHAEFER <schaefer@alphanet.ch>
# Creation: 08/02/97
# Update:   08/02/97
# V2.0 PV001
# DESCRIPTION
#    This script waits for the tape to become ready (ONLINE) and then
#    sets up characteristics for a DAT DDS2 drive.
# RESULT
#    0 ok, tape online
#    1 error
#    2 fatal error (parameters)
# NOTES
# BUGS
# TODO
# COPYING-POLICY
#   GPL
# BASED-ON
#   No previous work. First version (V2.0 is the project version).
# MODIFICATION-HISTORY
# $Id: tape_init.sh,v 1.2 1998/10/21 09:49:16 schaefer Exp $

if [ $# != 1 ]; then
   echo "$0 tape_device"
   echo "$0: bad args."
   exit 2
fi

TAPE_DEVICE=$1

mt -f $TAPE_DEVICE status > /dev/null
RESULT=$?
if [ $RESULT != 0 ]; then
   echo "$0: tape device $TAPE_DEVICE non existant."
   exit $RESULT
fi

# Waiting for online status

while :
do
   mt -f $TAPE_DEVICE status | egrep "ONLINE" > /dev/null
   if [ $? = 0 ]; then
      break
   else
      echo "$TAPE: not yet online"
      sleep 2
   fi
done


# Rewinding
mt -f $TAPE_DEVICE rewind
RESULT=$?
if [ $RESULT != 0 ]; then
   echo "$0: rewinding $TAPE_DEVICE failed."
   exit $RESULT
fi
# Parameter setting

# Variable block size.
mt -f $TAPE_DEVICE setblk 0
exit $?